==> zope_2.1.6.orig.tar.gz: Zope-2.1.6-src/ZServer/DebugLogger.py <==
##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################

import time, thread

class DebugLogger:
    """
    Logs debugging information about how ZServer is handling requests
    and responses. This log can be used to help locate troublesome requests.
    
    The format is:
    
        <code> <request id> <time> <data>
    
    where:
    
        'code' is B for begin, I for received input, A for received output,
            E for sent output.
        
        'request id' is a unique request id.
        
        'time' is the time in GMT ISO format.
        
        'data' is the HTTP method and the PATH INFO for B, the size of the input
            for I, the HTTP status code and the size of the output for A, or
            nothing for E.
            
    Note: This facility will be probably be adapted to the zLOG framework.
    """
    
    def __init__(self, filename):
        self.file=open(filename, 'a+b')
        l=thread.allocate_lock()
        self._acquire=l.acquire
        self._release=l.release
        
    def log(self, code, request_id, data=''):
        self._acquire()
        try:
            t=time.strftime('%Y-%m-%dT%H:%M:%S', time.gmtime(time.time()))
            self.file.write(
                '%s %s %s %s\n' % (code, request_id, t, data)
                )
            self.file.flush()
        finally:
            self._release()


def log(*args): pass

==> zope_2.5.1.orig.tar.gz: Zope-2.5.1-src/ZServer/DebugLogger.py <==
##############################################################################
#
# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
# 
##############################################################################

import time, thread

class DebugLogger:
    """
    Logs debugging information about how ZServer is handling requests
    and responses. This log can be used to help locate troublesome requests.
    
    The format is:
    
        <code> <request id> <time> <data>
    
    where:
    
        'code' is B for begin, I for received input, A for received output,
            E for sent output.
        
        'request id' is a unique request id.
        
        'time' is the time in localtime ISO format.
        
        'data' is the HTTP method and the PATH INFO for B, the size of the input
            for I, the HTTP status code and the size of the output for A, or
            nothing for E.
            
    Note: This facility will be probably be adapted to the zLOG framework.
    """
    
    def __init__(self, filename):
        self.file=open(filename, 'a+b')
        l=thread.allocate_lock()
        self._acquire=l.acquire
        self._release=l.release
        self.log('U', '000000000', 'System startup')
        
    def log(self, code, request_id, data=''):
        self._acquire()
        try:
            t=time.strftime('%Y-%m-%dT%H:%M:%S', time.localtime(time.time()))
            self.file.write(
                '%s %s %s %s\n' % (code, request_id, t, data)
                )
            self.file.flush()
        finally:
            self._release()


def log(*args): pass
